class get:
    def __str__(self):
            return self.text
    def __init__(self, url):
        import urllib.request
        self.url = url
        with open('text.txt', 'wb') as f:
                f.write(urllib.request.urlopen(url).read())
        with open('text.txt', 'rb') as f:
                a = f.read().decode()
                self.text = a



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="mython3",
    version="0.0.1.5",
    author="Will F",
    author_email="forsbergw82@gmail.com",
    description="LOTS OF NEW METHODS!!!",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=['mython3'],
    classifiers=[
        "Programming Language :: Python :: 3",
    ],
)
